@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -9,9 +10,9 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/python3.8/bin',
- 'BINLIBDEST': '/opt/python3.8/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
+ 'BINDIR': '/opt/python3.9/bin',
+ 'BINLIBDEST': '/opt/python3.9/lib/python3.9',
+ 'BLDLIBRARY': '-L. -lpython3.9',
  'BLDSHARED': 'gcc -pthread -shared -L/opt/openssl1.1.1g/lib/ '
               '-L/opt/openssl1.1.1g/lib64/ -L/opt/openssl1.1.1g/lib/ '
               '-L/opt/openssl1.1.1g/lib64/',
@@ -31,21 +32,22 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/opt/openssl1.1.1g/include '
                        '-I/opt/openssl1.1.1g/include/openssl',
  'CONFIGURE_LDFLAGS': '-L/opt/openssl1.1.1g/lib/ -L/opt/openssl1.1.1g/lib64/',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--enable-loadable-sqlite-extensions=yes' "
-                "'--prefix=/opt/python3.8' 'LDFLAGS=-L/opt/openssl1.1.1g/lib/ "
+                "'--prefix=/opt/python3.9' 'LDFLAGS=-L/opt/openssl1.1.1g/lib/ "
                 "-L/opt/openssl1.1.1g/lib64/' "
                 "'CPPFLAGS=-I/opt/openssl1.1.1g/include "
                 "-I/opt/openssl1.1.1g/include/openssl'",
- 'CONFINCLUDEDIR': '/opt/python3.8/include',
- 'CONFINCLUDEPY': '/opt/python3.8/include/python3.8',
+ 'CONFINCLUDEDIR': '/opt/python3.9/include',
+ 'CONFINCLUDEPY': '/opt/python3.9/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/buildserver/setup/Python-3.8.11/coverage.info',
- 'COVERAGE_REPORT': '/home/buildserver/setup/Python-3.8.11/lcov-report',
+ 'COVERAGE_INFO': '/home/buildserver/setup/Python-3.9.13/coverage.info',
+ 'COVERAGE_REPORT': '/home/buildserver/setup/Python-3.9.13/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/opt/openssl1.1.1g/include '
@@ -53,11 +55,11 @@ build_time_vars = {'ABIFLAGS': '',
              '-I/opt/openssl1.1.1g/include '
              '-I/opt/openssl1.1.1g/include/openssl',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/opt/python3.8 /opt/python3.8/lib /opt/python3.8/lib/python3.8 '
-             '/opt/python3.8/lib/python3.8/lib-dynload',
- 'DESTLIB': '/opt/python3.8/lib/python3.8',
+ 'DESTDIRS': '/opt/python3.9 /opt/python3.9/lib /opt/python3.9/lib/python3.9 '
+             '/opt/python3.9/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/opt/python3.9/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/python3.8/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/opt/python3.9/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -79,14 +81,15 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'upgrade',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-38-x86_64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-39-x86_64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -242,7 +245,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -274,18 +276,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 0,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 0,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 0,
  'HAVE_LINUX_MEMFD_H': 0,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 0,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 0,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -311,6 +318,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -337,7 +345,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 0,
@@ -362,6 +369,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 0,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -434,6 +442,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -489,7 +498,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -515,40 +523,40 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/opt/python3.8/include /opt/python3.8/include '
-                   '/opt/python3.8/include/python3.8 '
-                   '/opt/python3.8/include/python3.8',
- 'INCLUDEDIR': '/opt/python3.8/include',
- 'INCLUDEPY': '/opt/python3.8/include/python3.8',
+ 'INCLDIRSTOMAKE': '/opt/python3.9/include /opt/python3.9/include '
+                   '/opt/python3.9/include/python3.9 '
+                   '/opt/python3.9/include/python3.9',
+ 'INCLUDEDIR': '/opt/python3.9/include',
+ 'INCLUDEPY': '/opt/python3.9/include/python3.9',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
  'LDFLAGS': '-L/opt/openssl1.1.1g/lib/ -L/opt/openssl1.1.1g/lib64/ '
             '-L/opt/openssl1.1.1g/lib/ -L/opt/openssl1.1.1g/lib64/',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared -L/opt/openssl1.1.1g/lib/ '
              '-L/opt/openssl1.1.1g/lib64/ -L/opt/openssl1.1.1g/lib/ '
              '-L/opt/openssl1.1.1g/lib64/',
- 'LDVERSION': '3.8',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/opt/python3.8/lib/python3.8',
- 'LIBDIR': '/opt/python3.8/lib',
+ 'LIBDEST': '/opt/python3.9/lib/python3.9',
+ 'LIBDIR': '/opt/python3.9/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/python3.8/lib/pkgconfig',
- 'LIBPL': '/opt/python3.8/lib/python3.8/config-3.8-x86_64-linux-gnu',
+ 'LIBPC': '/opt/python3.9/lib/pkgconfig',
+ 'LIBPL': '/opt/python3.9/lib/python3.9/config-3.9-x86_64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
@@ -564,18 +572,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/python3.8/lib/python3.8',
+ 'MACHDESTLIB': '/opt/python3.9/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/python3.8/share/man',
+ 'MANDIR': '/opt/python3.9/share/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -588,7 +596,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
@@ -608,9 +616,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -626,16 +638,16 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I./Include/internal -I. -I./Include '
-                             '-I/opt/openssl1.1.1g/include '
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -I/opt/openssl1.1.1g/include '
                              '-I/opt/openssl1.1.1g/include/openssl '
                              '-I/opt/openssl1.1.1g/include '
                              '-I/opt/openssl1.1.1g/include/openssl -fPIC '
@@ -643,13 +655,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I./Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -std=c99 -Wextra -Wno-unused-result '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include '
                    '-I/opt/openssl1.1.1g/include '
                    '-I/opt/openssl1.1.1g/include/openssl '
@@ -670,9 +682,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I./Include/internal -I. -I./Include '
-                        '-I/opt/openssl1.1.1g/include '
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -I/opt/openssl1.1.1g/include '
                         '-I/opt/openssl1.1.1g/include/openssl '
                         '-I/opt/openssl1.1.1g/include '
                         '-I/opt/openssl1.1.1g/include/openssl -fPIC',
@@ -684,10 +696,9 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.8.11:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/',
- 'SCRIPTDIR': '/opt/python3.8/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.9.13:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/',
+ 'SCRIPTDIR': '/opt/python3.9/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
  'SHLIB_SUFFIX': '.so',
@@ -712,8 +723,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-x86_64-linux-gnu',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-39-x86_64-linux-gnu',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -726,20 +737,21 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.8.11:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.9.13:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.8.11:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/buildserver/setup/Python-3.9.13:/opt/openssl1.1.1g/lib/:/opt/openssl1.1.1g/lib64/ '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.8',
+ 'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -751,9 +763,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/buildserver/setup/Python-3.8.11',
- 'abs_srcdir': '/home/buildserver/setup/Python-3.8.11',
- 'datarootdir': '/opt/python3.8/share',
- 'exec_prefix': '/opt/python3.8',
- 'prefix': '/opt/python3.8',
+ 'abs_builddir': '/home/buildserver/setup/Python-3.9.13',
+ 'abs_srcdir': '/home/buildserver/setup/Python-3.9.13',
+ 'datarootdir': '/opt/python3.9/share',
+ 'exec_prefix': '/opt/python3.9',
+ 'prefix': '/opt/python3.9',
  'srcdir': '.'}
